@@ -1,5 +1,6 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
+from decimal import Decimal
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.model.cacheable import Cacheable
 from trytond.pyson import Eval
@@ -90,7 +91,7 @@ class EmployeeCostPrice(ModelSQL, ModelView):
     _name = 'company.employee_cost_price'
     _description = __doc__
     _rec_name = 'date'
-    date = fields.Date('Date', required=True, select=1)
+    date = fields.Date('Date', required=True, select=True)
     cost_price = fields.Numeric('Cost Price',
             digits=(16, Eval('currency_digits', 2)),
             required=True, depends=['currency_digits'],
@@ -107,21 +108,24 @@ class EmployeeCostPrice(ModelSQL, ModelView):
         ]
         self._order.insert(0, ('date', 'DESC'))
 
+    def default_cost_price(self):
+        return Decimal(0)
+
     def default_date(self):
         date_obj = Pool().get('ir.date')
         return date_obj.today()
 
     def delete(self, ids):
         Pool().get('company.employee').clear()
-        return super(EmployeeCostPrice , self).delete(ids)
+        return super(EmployeeCostPrice, self).delete(ids)
 
     def create(self, vals):
         Pool().get('company.employee').clear()
-        return super(EmployeeCostPrice , self).create(vals)
+        return super(EmployeeCostPrice, self).create(vals)
 
     def write(self, ids, vals):
         Pool().get('company.employee').clear()
-        return super(EmployeeCostPrice , self).write(ids, vals)
+        return super(EmployeeCostPrice, self).write(ids, vals)
 
     def get_currency_digits(self, ids, name):
         res = {}
