@@ -29,25 +29,22 @@ class TimesheetLine(ModelSQL, ModelView):
 
 TimesheetLine()
 
+
 class Work(ModelSQL, ModelView):
     'Work Effort'
     _name = 'project.work'
 
     product = fields.Many2One('product.product', 'Product',
         states={
-            'invisible': Eval('type') != 'task',
-            }, on_change=['product', 'party', 'hours', 'company'],
-            depends=['type', 'party', 'hours', 'company'])
+            'invisible': ~Eval('timesheet_available'),
+            },
+        depends=['timesheet_available'],
+        on_change=['product', 'party', 'hours', 'company'])
     list_price = fields.Numeric('List Price',
-        digits=(16, Eval('currency_digits', 2)),
-        states={
-            'invisible': Eval('type') != 'task',
-            }, depends=['type', 'currency_digits'])
+        digits=(16, Eval('currency_digits', 2)), depends=['currency_digits'])
     revenue = fields.Function(fields.Numeric('Revenue',
             digits=(16, Eval('currency_digits', 2)),
-            states={
-                'invisible': Eval('type') != 'project',
-                }, depends=['type', 'currency_digits']), 'get_revenue')
+            depends=['currency_digits']), 'get_revenue')
     cost = fields.Function(fields.Numeric('Cost',
         digits=(16, Eval('currency_digits', 2)), depends=['currency_digits']),
         'get_cost')
@@ -104,8 +101,9 @@ class Work(ModelSQL, ModelView):
             if not work.children:
                 leafs.add(work.id)
 
-            if work.type == 'task':
-                res[work.id] = work.list_price * Decimal(str(work.total_effort))
+            if work.type == 'task' and work.list_price:
+                res[work.id] = (work.list_price
+                    * Decimal(str(work.total_effort)))
             else:
                 res[work.id] = Decimal('0')
 
@@ -154,6 +152,7 @@ class Work(ModelSQL, ModelView):
         company_obj = pool.get('company.company')
         model_data_obj = pool.get('ir.model.data')
         uom_obj = pool.get('product.uom')
+        currency_obj = pool.get('currency.currency')
 
         if not vals.get('product'):
             return {}
